; assembler part of object manipulation module

	.include	"jaguar.inc"

; Globals
		.globl	_ObjSetOlp
		.globl	_ObjInitVbint

; Externals
		.extern _VidVdb
		.extern _VidVde
		.extern _VidHdb
		.extern _VidHde
		.extern _VidWidth
		.extern _VidHeight

; GPU Code
; Procedure: gSetOLP
;            Use the GPU to set the OLP and quit.
;
;    Inputs: olp2set - Variable contains pre-swapped value to stuff OLP with.
;
; GPU function for setting the object processor
; the GPU has to do this because the 68000 writes
; the long word in 2 halves, and if the object processor
; runs in between the writes then it will blow up
;
; NOTE!!!: This code can run in DRAM only because it contains no JUMP's or
;          JR's. It will generate a warning with current versions of MADMAC
;          because it doesn't '.ORG'.
;
		.long
		.gpu
gSetOLP:
		movei   #olp2set,r0   		; Read value to write
		load    (r0),r1

		movei   #OLP,r0       		; Store it
		store   r1,(r0)

		moveq   #0,r0         		; Stop GPU
		movei   #G_CTRL,r1
		store   r0,(r1)
		nop             		; Two "feet" on the brake pedal
		nop

		.68000
		.bss
		.long

olp2set:    	.ds.l   1           		; GPU Code Parameter

		.text

; Procedure: void obj_set_olp(void *obj_list,
;                             long backup_entries,
;                             void *bitmap_backup)
_ObjSetOlp:
		move.l	d0,-(sp)
		move.l	12(sp),d0		; parameter num_entries
		move.l	d0,bmpnum
		move.l	16(sp),d0		; parameter bitmap_backup
		move.l	d0,bmpptr
		move.l	8(sp),d0		; parameter obj_list
		swap    d0			; swap d0 for OLP
		move.l  d0,olp2set
		move.l  #gSetOLP,G_PC   	; Set GPU PC
		move.l  #RISCGO,G_CTRL  	; Go!
setolpwait:
		move.l  G_CTRL,d0   		; Wait for write.
		andi.l  #$1,d0
		bne 	setolpwait
		move.w  #$6C7,VMODE     	; Configure Video
		move.l	(sp)+,d0
		rts


; Procedure: void init_vb_int(void)
; Install our vertical blank handler and enable interrupts
_ObjInitVbint:
		move.l  d0,-(sp)
		move.l  #UpdateList,LEVEL0	; Install 68K LEVEL0 handler
		move.w  _VidVde,d0        	; Must be ODD
		ori.w   #1,d0
		move.w  d0,VI
		move.w  #C_VIDENA,INT1         	; Enable video interrupts
		move.w  sr,d0
		and.w   #$F8FF,d0       	; Lower 68k IPL to allow
		move.w  d0,sr           	; interrupts
		move.l  (sp)+,d0
		rts

; Procedure: UpdateList
; Handle Video Interrupt and update object list fields
; destroyed by the object processor.
UpdateList:
		movem.l	d0/a0-a1,-(sp)

		move.l	bmpnum,d0		; no of entries

UpdateLoop:	move.l  bmpptr,a0		; a0 is pointer to backup entry
		move.l  (a0),a1			; ai is pointer to bitmap
		move.l  4(a0),(a1)      	; Phrase = d1.l/d0.l
		move.l  8(a0),4(a1)
		subq.l	#1,d0
		bne	UpdateLoop

		add.l	#1,ticks		; Increment ticks semaphore

		move.w  #$101,INT1      	; Signal we're done
		move.w  #$0,INT2

		movem.l	(sp)+,d0/a0-a1
		rte


		.bss
ticks:		.ds.l	1			; Incrementing # of ticks
bmpptr:    	.ds.l   1	  		; Pointer to bitmap backup list
bmpnum:		.ds.l	1			; No of bitmap backup entries

		.end
